==> flutter_vizzy_lib-1.0.0.tar.gz: lib/VizzyApiClient.dart <==
import 'dart:io';

import 'package:json_annotation/json_annotation.dart';
import 'package:retrofit/retrofit.dart';
import 'package:dio/dio.dart';

part 'VizzyApiClient.g.dart';

@RestApi()
abstract class VizzyApiClient {
  factory VizzyApiClient(Dio dio) = _VizzyApiClient;

  @POST("builds.json")
  Future<BuildInfo> createBuild(@Header("Content-Type") String contentType, @Body() CreateBuildRequest build);

  @POST("test_images.json")
  Future<UploadImageResponse> uploadImage(@Field('build_id') int buildId, @Field('image') File image, @Field('test_image_ancestry') String fileName);

  @POST("builds/{id}/add_md5s.json")
  Future<ImageMd5Response> postImageMd5s(@Header("Content-Type") String contentType, @Path("id") int buildId, @Body() ImageMd5Request imageRequest);

  @POST("builds/{id}/commit.json")
  Future<BuildState> commitBuild(@Path("id") int buildId);

  @GET("builds/{id}/commit.json")
  Future<BuildState> getBuildState(@Path("id") int buildId);
}

@JsonSerializable()
class BuildInfo {
  var id = 0;

  BuildInfo({this.id});

  factory BuildInfo.fromJson(Map<String, dynamic> json) => _$BuildInfoFromJson(json);
  Map<String, dynamic> toJson() => _$BuildInfoToJson(this);
}

@JsonSerializable()
class CreateBuildRequest {

  CreateBuildRequest({this.projectId, this.devBuild, this.pullRequestNumber, this.commitSha});

  @JsonKey(name: "project_id")
  var projectId = 1;

  @JsonKey(name: "dev_build")
  bool devBuild = false;

  // A pull_request_number of -1 means a master build
  // A pull_request_number of something else will make a PR build
  // A dev build will not require PR number or commit sha
  @JsonKey(name: "pull_request_number", required: false, includeIfNull: false)
  String pullRequestNumber;

  @JsonKey(name: "commit_sha", required: false, includeIfNull: false)
  String commitSha;

  factory CreateBuildRequest.fromJson(Map<String, dynamic> json) => _$CreateBuildRequestFromJson(json);
  Map<String, dynamic> toJson() => _$CreateBuildRequestToJson(this);

}

@JsonSerializable()
class ImageMd5Request {

  ImageMd5Request({this.imageMd5s});

  @JsonKey(name: "image_md5s")
  String imageMd5s = "{}";

  factory ImageMd5Request.fromJson(Map<String, dynamic> json) => _$ImageMd5RequestFromJson(json);
  Map<String, dynamic> toJson() => _$ImageMd5RequestToJson(this);
}


@JsonSerializable()
class ImageMd5Response {

  ImageMd5Response({this.imageMd5s});

  @JsonKey(name: "image_md5s")
  Map<String, String> imageMd5s;

  factory ImageMd5Response.fromJson(Map<String, dynamic> json) => _$ImageMd5ResponseFromJson(json);
  Map<String, dynamic> toJson() => _$ImageMd5ResponseToJson(this);
}

@JsonSerializable()
class UploadImageResponse {

  UploadImageResponse();

  factory UploadImageResponse.fromJson(Map<String, dynamic> json) => _$UploadImageResponseFromJson(json);
  Map<String, dynamic> toJson() => _$UploadImageResponseToJson(this);
}

@JsonSerializable()
class BuildState {

  BuildState({this.committed});

  @JsonKey(name: "committed")
  bool committed = false;

  factory BuildState.fromJson(Map<String, dynamic> json) => _$BuildStateFromJson(json);
  Map<String, dynamic> toJson() => _$BuildStateToJson(this);
}

==> flutter_vizzy_lib-1.0.1.tar.gz: lib/VizzyApiClient.dart <==
import 'dart:io';

import 'package:json_annotation/json_annotation.dart';
import 'package:retrofit/retrofit.dart';
import 'package:dio/dio.dart';

part 'VizzyApiClient.g.dart';

@RestApi()
abstract class VizzyApiClient {
  factory VizzyApiClient(Dio dio) = _VizzyApiClient;

  @POST("builds.json")
  Future<BuildInfo> createBuild(@Header("Content-Type") String contentType, @Body() CreateBuildRequest build);

  @POST("test_images.json")
  Future<UploadImageResponse> uploadImage(@Part('build_id') int buildId, @Part('image') File image, @Part('test_image_ancestry') String fileName);

  @POST("builds/{id}/add_md5s.json")
  Future<ImageMd5Response> postImageMd5s(@Header("Content-Type") String contentType, @Path("id") int buildId, @Body() ImageMd5Request imageRequest);

  @POST("builds/{id}/commit.json")
  Future<BuildState> commitBuild(@Path("id") int buildId);

  @GET("builds/{id}/commit.json")
  Future<BuildState> getBuildState(@Path("id") int buildId);
}

@JsonSerializable()
class BuildInfo {
  var id = 0;

  BuildInfo({this.id});

  factory BuildInfo.fromJson(Map<String, dynamic> json) => _$BuildInfoFromJson(json);
  Map<String, dynamic> toJson() => _$BuildInfoToJson(this);
}

@JsonSerializable()
class CreateBuildRequest {

  CreateBuildRequest({this.projectId, this.devBuild, this.pullRequestNumber, this.commitSha});

  @JsonKey(name: "project_id")
  var projectId = 1;

  @JsonKey(name: "dev_build")
  bool devBuild = false;

  // A pull_request_number of -1 means a master build
  // A pull_request_number of something else will make a PR build
  // A dev build will not require PR number or commit sha
  @JsonKey(name: "pull_request_number", required: false, includeIfNull: false)
  String pullRequestNumber;

  @JsonKey(name: "commit_sha", required: false, includeIfNull: false)
  String commitSha;

  factory CreateBuildRequest.fromJson(Map<String, dynamic> json) => _$CreateBuildRequestFromJson(json);
  Map<String, dynamic> toJson() => _$CreateBuildRequestToJson(this);

}

@JsonSerializable()
class ImageMd5Request {

  ImageMd5Request({this.imageMd5s});

  @JsonKey(name: "image_md5s")
  String imageMd5s = "{}";

  factory ImageMd5Request.fromJson(Map<String, dynamic> json) => _$ImageMd5RequestFromJson(json);
  Map<String, dynamic> toJson() => _$ImageMd5RequestToJson(this);
}


@JsonSerializable()
class ImageMd5Response {

  ImageMd5Response({this.imageMd5s});

  @JsonKey(name: "image_md5s")
  Map<String, String> imageMd5s;

  factory ImageMd5Response.fromJson(Map<String, dynamic> json) => _$ImageMd5ResponseFromJson(json);
  Map<String, dynamic> toJson() => _$ImageMd5ResponseToJson(this);
}

@JsonSerializable()
class UploadImageResponse {

  UploadImageResponse();

  factory UploadImageResponse.fromJson(Map<String, dynamic> json) => _$UploadImageResponseFromJson(json);
  Map<String, dynamic> toJson() => _$UploadImageResponseToJson(this);
}

@JsonSerializable()
class BuildState {

  BuildState({this.committed});

  @JsonKey(name: "committed")
  bool committed = false;

  factory BuildState.fromJson(Map<String, dynamic> json) => _$BuildStateFromJson(json);
  Map<String, dynamic> toJson() => _$BuildStateToJson(this);
}
